@@ -5,14 +5,12 @@ import multiprocessing as mp
 import os
 import time
 
-import h5py
 import numpy as np
 import pandas as pd
 import pennylane as qml
 import psutil
 import scipy as sp
 from matplotlib import pyplot as plt
-from numba import cuda
 from sklearn.preprocessing import MinMaxScaler
 
 from .GA_ABC import GA_Individual, GA_Model
@@ -153,7 +151,12 @@ class Individual(GA_Individual):
 
     def ansatz_circuit(self, params, event=None, ansatz=None):
         for m in ansatz:
-            exec(m)
+            # exec(m)
+            try:
+                exec(m)
+            except:
+                print(m)
+                raise Exception("oopsies there's a problem")
         return qml.expval(qml.PauliZ(wires=[self.n_qubits - 1]))
 
     def draw_ansatz(self):
@@ -215,6 +218,7 @@ class Model(GA_Model):
         self.n_shots = config["n_shots"]
         self.events = config["events"]
         self.train_size = config["train_size"]
+        self.batch_size = config["batch_size"]
 
         self.start_time = datetime.datetime.now().strftime("%Y-%m-%d_%H-%M-%S")
         self.script_path = os.path.dirname(os.path.realpath(__file__))
@@ -327,6 +331,7 @@ class Model(GA_Model):
                     p.params,
                     event_sub,
                     self.train_size,
+                    self.batch_size,
                     self.n_qubits,
                     self.latent_qubits,
                     self.rng_seed,
@@ -336,8 +341,11 @@ class Model(GA_Model):
                     self.n_shots,
                 )
             )
+            print(len(args_arr[ix]))
             ix += 1
 
+        print(args_arr[0])
+
         start_time = time.time()
         for i in range(self.pop_size // self.max_concurrent):
             with mp.get_context("spawn").Pool(processes=len(args_arr)) as pool:
